"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveTokenRegistry = void 0;
const spl_token_registry_1 = require("@solana/spl-token-registry");
let tokenRegistry = undefined;
/**
 * Resolves the token registry using _static_ stragegy for speed over up-to-dateness.
 * @category diagnostics
 * @private
 */
async function resolveTokenRegistry() {
    if (tokenRegistry == null) {
        try {
            await new spl_token_registry_1.TokenListProvider()
                .resolve(spl_token_registry_1.Strategy.Static)
                .then((tokens) => {
                const tokenList = tokens.getList();
                tokenRegistry = tokenList.reduce((map, item) => {
                    map.set(item.address, item);
                    return map;
                }, new Map());
            });
        }
        catch (err) {
            return new Map();
        }
    }
    return tokenRegistry;
}
exports.resolveTokenRegistry = resolveTokenRegistry;
//# sourceMappingURL=token-registry.js.map