"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockStorageServer = void 0;
const fs_1 = __importDefault(require("fs"));
const http_1 = __importDefault(require("http"));
const path_1 = __importDefault(require("path"));
const _1 = require(".");
const utils_1 = require("../utils");
const fs_2 = require("../utils/fs");
const types_1 = require("./types");
class MockStorageServer {
    constructor(storageDir) {
        this.storageDir = storageDir;
        (0, fs_2.ensureDirSync)(this.storageDir);
    }
    static get existingInstance() {
        return MockStorageServer._instance;
    }
    static async createInstance(storageConfig) {
        if (MockStorageServer._instance == null) {
            const { storageId, clearOnStart } = {
                ...types_1.DefaultStorageConfig,
                ...storageConfig,
            };
            const storageDir = path_1.default.join(_1.AMMAN_STORAGE_ROOT, storageId);
            if (clearOnStart) {
                await (0, fs_2.ensureDirCleaned)(storageDir);
                (0, utils_1.logDebug)(`MockStorageServer cleared ${storageDir}`);
            }
            return (MockStorageServer._instance = new MockStorageServer(storageDir));
        }
        else {
            throw new Error('MockStorageServer instance can only be created once');
        }
    }
    start() {
        this.server = http_1.default
            .createServer(async (req, res) => {
            (0, utils_1.logTrace)(`MockStorageServer: handling ${req.url}`);
            const resource = path_1.default.join(_1.AMMAN_STORAGE_ROOT, req.url.slice(1));
            if (!(await (0, fs_2.canRead)(resource))) {
                (0, utils_1.logError)(`MockStorageServer: failed to find ${resource}`);
                res.writeHead(404).end();
            }
            else {
                (0, utils_1.logDebug)(`MockStorageServer: serving ${resource}`);
                res.writeHead(200, {
                    'Access-Control-Allow-Origin': '*',
                    'Access-Control-Allow-Methods': 'OPTIONS, POST, GET',
                    'Access-Control-Max-Age': 2592000, // 30 days
                });
                fs_1.default.createReadStream(resource).pipe(res);
            }
        })
            .unref();
        const promise = new Promise((resolve, reject) => {
            this.server.on('error', reject).on('listening', () => resolve(this.server));
        });
        this.server.listen(_1.AMMAN_STORAGE_PORT);
        return promise;
    }
    stop() {
        var _a;
        (_a = this.server) === null || _a === void 0 ? void 0 : _a.close();
    }
}
exports.MockStorageServer = MockStorageServer;
//# sourceMappingURL=mock-server.js.map