/// <reference types="@lorisleiva/js-next-alpha/node_modules/@solana/web3.js" />
import { Connection, Keypair, SendOptions, Signer, Transaction } from '@solana/web3.js';
import { ConfirmedTransactionDetails, TransactionHandler } from './types';
import type { ErrorResolver } from '@metaplex-foundation/cusper';
export declare type TransactionLabelMapper = (label: string) => string;
/**
 * A {@link TransactionHandler} backed by a payer {@link Keypair}.
 * @category transactions
 */
export declare class PayerTransactionHandler implements TransactionHandler {
    private readonly connection;
    private readonly payer;
    private readonly errorResolver?;
    private readonly transactionLabelMapper;
    /**
     * Creates a {@link PayerTransactionHandler}.
     *
     * @param connection to use to handle transactions
     * @param payer to use to sign transactions
     * @param errorResolver used to resolve a known error from the program logs
     */
    constructor(connection: Connection, payer: Keypair, errorResolver?: ErrorResolver | undefined, transactionLabelMapper?: TransactionLabelMapper);
    /**
     * Public key of the payer
     */
    get publicKey(): import("@solana/web3.js").PublicKey;
    /**
     * Sends and confirms the transaction {@link TransactionHandler['sendAndConfirmTransaction']}.
     */
    sendAndConfirmTransaction(transaction: Transaction, signers: Array<Signer>, optionsOrLabel?: SendOptions | string, label?: string): Promise<ConfirmedTransactionDetails>;
}
